@@ -6,6 +6,7 @@ use warnings;
 use parent 'RPi::WiringPi::Util';
 
 use RPi::ADC::ADS;
+use RPi::DigiPot::MCP4XXXX;
 use RPi::SPI;
 use RPi::WiringPi::Constant qw(:all);
 use RPi::WiringPi::BMP180;
@@ -13,7 +14,7 @@ use RPi::WiringPi::Interrupt;
 use RPi::WiringPi::LCD;
 use RPi::WiringPi::Pin;
 
-our $VERSION = '2.36.4';
+our $VERSION = '2.36.5';
 
 my $fatal_exit = 1;
 
@@ -85,6 +86,11 @@ sub adc {
     my $adc = RPi::ADC::ADS->new(%args);
     return $adc;
 }
+sub dpot {
+    my ($self, $cs, $channel) = @_;
+    my $dpot = RPi::DigiPot::MCP4XXXX->new($cs, $channel);
+    return $dpot;
+}
 sub pin {
     my ($self, $pin_num) = @_;
 
@@ -186,6 +192,23 @@ various items
 
     $spi->rw($buf, $len);
 
+    #
+    # digital potentiometer
+    #
+
+    my $cs = 18;     # GPIO pin connected to dpot CS pin
+    my $channel = 0; # SPI channel /dev/spidev0.0
+
+    my $dpot = $pi->dpot($cs, $channel);
+
+    # set to 50% output
+
+    $dpot->set(127);
+
+    # shutdown (sleep) the potentiometer
+
+    $dpot->shutdown;
+
     #
     # shift register
     #
@@ -338,6 +361,14 @@ Peripheral Interface (SPI) bus with attached devices.
 See the linked documentation for full documentation on usage, or the
 L<RPi::WiringPi::FAQ-Tutorial> for usage examples.
 
+=head2 dpot($cs, $channel)
+
+Returns a L<RPi::DigiPot::MCP4XXXX> object, which allows you to manage a
+digital potentiometer (only the MCP4XXXX versions are currently supported).
+
+See the linked documentation for full documentation on usage, or the
+L<RPi::WiringPi::FAQ-Tutorial> for usage examples.
+
 =head2 shift_register($base, $num_pins, $data, $clk, $latch)
 
 Allows you to access the output pins of up to four 74HC595 shift registers in
